@@ -29,6 +29,9 @@ FAILEDOPERATION_ASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.AssociateSecuri
 # 实例安全组信息清除失败。
 FAILEDOPERATION_CLEARINSTANCEINFOFAILED = 'FailedOperation.ClearInstanceInfoFailed'
 
+# 提交工作流失败。
+FAILEDOPERATION_COMMITFLOWERROR = 'FailedOperation.CommitFlowError'
+
 # 解绑安全组失败。
 FAILEDOPERATION_DISASSOCIATESECURITYGROUPSFAILED = 'FailedOperation.DisassociateSecurityGroupsFailed'
 
@@ -65,6 +68,9 @@ FAILEDOPERATION_UPDATEINSTANCEINFOFAILED = 'FailedOperation.UpdateInstanceInfoFa
 # 更新安全组失败。
 FAILEDOPERATION_UPDATESECURITYGROUPSFAILED = 'FailedOperation.UpdateSecurityGroupsFailed'
 
+# cam鉴权错误。
+INTERNALERROR_CAMAUTHOSSRESPONSERETURNCODEERROR = 'InternalError.CamAuthOssResponseReturnCodeError'
+
 # 统一的 DB 操作错误，可以是 update insert select..。
 INTERNALERROR_DBOPERATIONFAILED = 'InternalError.DbOperationFailed'
 
@@ -92,6 +98,9 @@ INVALIDPARAMETER_ILLEGALPARAMETERERROR = 'InvalidParameter.IllegalParameterError
 # 业务参数错误。
 INVALIDPARAMETER_INVALIDPARAMETER = 'InvalidParameter.InvalidParameter'
 
+# 参数错误，不支持操作。
+INVALIDPARAMETER_NOTSUPPORTED = 'InvalidParameter.NotSupported'
+
 # 上海金融只提供vpc网络。
 INVALIDPARAMETER_ONLYVPCONSPECZONEID = 'InvalidParameter.OnlyVPCOnSpecZoneId'
 
